pub struct Auth { /* private fields */ }Expand description
The auth middleware layer.
Implementations
Sourceimpl Auth
impl Auth
Sourcepub async fn fetch_from_url<D: DeserializeOwned>(
&self,
url: &str,
headers: HeaderMap,
) -> HtsGetResult<D>
pub async fn fetch_from_url<D: DeserializeOwned>( &self, url: &str, headers: HeaderMap, ) -> HtsGetResult<D>
Fetch JWKS from the authorization server.
Sourcepub async fn decode_jwks(
&self,
jwks_url: &Uri,
token: &str,
) -> HtsGetResult<DecodingKey>
pub async fn decode_jwks( &self, jwks_url: &Uri, token: &str, ) -> HtsGetResult<DecodingKey>
Get a decoding key form the JWKS url.
Sourcepub fn decode_public_key(key: &[u8]) -> HtsGetResult<DecodingKey>
pub fn decode_public_key(key: &[u8]) -> HtsGetResult<DecodingKey>
Decode a public key into an RSA, EdDSA or ECDSA pem-formatted decoding key.
Query the authorization service to get the restrictions. This function validates that the authorization url is trusted in the config settings before calling the service. The claims are assumed to be valid.
Sourcepub fn validate_restrictions(
restrictions: AuthorizationRestrictions,
request: Request,
endpoint: Endpoint,
) -> HtsGetResult<()>
pub fn validate_restrictions( restrictions: AuthorizationRestrictions, request: Request, endpoint: Endpoint, ) -> HtsGetResult<()>
Validate the restrictions, returning an error if the user is not authorized.
Sourcepub async fn validate_jwt(
&self,
headers: &HeaderMap,
) -> HtsGetResult<TokenData<Value>>
pub async fn validate_jwt( &self, headers: &HeaderMap, ) -> HtsGetResult<TokenData<Value>>
Validate only the JWT without looking up restrictions and validating those. Returns the decoded JWT token.
Validate the authorization flow, returning an error if the user is not authorized. This performs the following steps:
- Finds the JWT decoding key from the config or by querying a JWKS url.
- Validates the JWT token according to the config.
- Queries the authorization service for restrictions based on the config or JWT claims.
- Validates the restrictions to determine if the user is authorized.
Validate authorization flow according to validate_authorization and validate_jwt.
This function will only validate_jwt on service-info requests, and will otherwise
validate_authorization for htsget requests to /reads or /variants.