Struct htsget_http::ServiceInfo
source · pub struct ServiceInfo {
pub id: String,
pub name: String,
pub version: String,
pub organization: Organisation,
pub service_type: Type,
pub htsget: Htsget,
pub contact_url: String,
pub documentation_url: String,
pub created_at: String,
pub updated_at: String,
pub environment: String,
}Expand description
A struct representing the information that should be present in a service-info response.
Fields
id: Stringname: Stringversion: Stringorganization: Organisationservice_type: Typehtsget: Htsgetcontact_url: Stringdocumentation_url: Stringcreated_at: Stringupdated_at: Stringenvironment: StringTrait Implementations
sourceimpl Debug for ServiceInfo
impl Debug for ServiceInfo
sourceimpl Default for ServiceInfo
impl Default for ServiceInfo
sourcefn default() -> ServiceInfo
fn default() -> ServiceInfo
Returns the “default value” for a type. Read more
sourceimpl<'de> Deserialize<'de> for ServiceInfo
impl<'de> Deserialize<'de> for ServiceInfo
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<ServiceInfo> for ServiceInfo
impl PartialEq<ServiceInfo> for ServiceInfo
sourcefn eq(&self, other: &ServiceInfo) -> bool
fn eq(&self, other: &ServiceInfo) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl Serialize for ServiceInfo
impl Serialize for ServiceInfo
impl Eq for ServiceInfo
impl StructuralEq for ServiceInfo
impl StructuralPartialEq for ServiceInfo