Crate htsget_http
source ·Structs
Configuration for the htsget server.
Configuration of the service info.
Configuration for the htsget server.
A struct to represent a POST request according to the
HtsGet specification. It implements
Deserialize to make it more ergonomic. Each
PostRequest can contain several regions.A struct that contains the data to quest for a specific region. It is only meant to be use
alongside a
PostRequestS3 configuration for the htsget server.
A struct representing the information that should be present in a service-info response.
Configuration for the htsget ticket server.
Enums
A enum to distinguish between the two endpoint defined in the
HtsGet specification
An error type that describes the errors specified in the
HtsGet specification
Specify the storage type to use.
Functions
Gets a JSON response for a GET request. The GET request parameters must
be in a HashMap. The “id” field is the only mandatory one. The rest can be
consulted here